#!/bin/bash
#
#    post-cplane-configuration.sh
#    Copyright (C) 2017 Canonical Ltd.
#
#    Authors: Omar Lara <omar.lara@canonical.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, version 3 of the License.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

set -ex

CONTROLLER=maas
MODEL=cplane
KEYSTONE_PASSWD=openstack

echo "This command is run to configure an Orange-Box Openstack deployment with Cplane Networks SDN"

obnum=`hostname | cut -c 10- -`

PKGS=" python-keystone python-neutronclient python-novaclient python-glanceclient python-openstackclient jq"
dpkg -l $PKGS > /dev/null || sudo apt-get install -y $PKGS

NEUTRON_DNS="172.27.$((obnum+3)).254"

NEUTRON_EXT_NET_NAME="ext-net"
NEUTRON_EXT_NET_GW="172.27.$((obnum+3)).254"
NEUTRON_EXT_NET_CIDR="172.27.$((obnum+2)).0/23"
NEUTRON_EXT_NET_FLOAT_RANGE_START="172.27.$((obnum+3)).100"
NEUTRON_EXT_NET_FLOAT_RANGE_END="172.27.$((obnum+3)).149"

#NEUTRON_FIXED_NET_CIDR="192.168.$((obnum)).0/24"
NEUTRON_FIXED_NET_CIDR="192.168.20.0/24"
NEUTRON_FIXED_NET_NAME="tenant-net"

keystone=$(juju status -m $CONTROLLER:$MODEL keystone | grep keystone/0 | awk '{print $5}' )

echo "#!/bin/bash
export OS_USERNAME=admin
export OS_PASSWORD=$KEYSTONE_PASSWD
export OS_TENANT_NAME=admin
export OS_REGION_NAME=RegionOne
export OS_AUTH_URL=${OS_AUTH_PROTOCOL:-http}://$keystone:5000/v2.0
" > nova.rc

source nova.rc

neutron net-create $NEUTRON_FIXED_NET_NAME --provider:network_type local
neutron subnet-create $NEUTRON_FIXED_NET_NAME $NEUTRON_FIXED_NET_CIDR --name tenant-subnet
#
neutron net-create $NEUTRON_EXT_NET_NAME --router:external=True --provider:network_type local
neutron subnet-create --name ext-subnet --gateway $NEUTRON_EXT_NET_GW --allocation-pool start=$NEUTRON_EXT_NET_FLOAT_RANGE_START,end=$NEUTRON_EXT_NET_FLOAT_RANGE_END --disable-dhcp ext-net $NEUTRON_EXT_NET_CIDR

neutron router-create tenant-router 
neutron router-interface-add tenant-router tenant-subnet 
neutron router-gateway-set tenant-router ext-net


#Configure the default security group to allow ICMP and SSH
openstack security group rule create --proto icmp default
openstack security group rule create --proto tcp --dst-port 22 default
openstack security group rule create --proto tcp --dst-port 80 default
openstack security group rule create --proto tcp --dst-port 443 default
openstack security group rule create --proto tcp --dst-port 3389 default
openstack security group rule create --proto tcp --dst-port 8081 default

#Upload a default SSH key
openstack keypair create  --public-key ~/.ssh/id_rsa.pub default

#Remove the m1.tiny as it is too small for Ubuntu.

for i in tiny small medium large xlarge ; do openstack flavor delete m1.$i ; done 

openstack flavor create m1.small --id auto --ram 1024 --disk 20 --vcpus 2
openstack flavor create m1.medium --id auto --ram 2048 --disk 20 --vcpus 2
openstack flavor create m1.large --id auto --ram 4096 --disk 20 --vcpus 4

#Modify quotas for the tenant to allow large deployments
openstack quota  set --ram 204800 --cores 200 --instances 100 admin
neutron quota-update --security-group 100 --security-group-rule 500 

#Upload images to glance

glance image-create --name=Trusty-QCOW --visibility=public --container-format=ovf --disk-format=qcow2 <  /srv/data/trusty-server-cloudimg-amd64-disk1.img
glance image-create --name=Xenial-QCOW --visibility=public --container-format=ovf --disk-format=qcow2 <  /srv/data/xenial-server-cloudimg-amd64-disk1.img
glance image-create --name=Cirros-QCOW --visibility=public --container-format=ovf --disk-format=qcow2 <  /srv/data/cirros-0.3.2-x86_64-disk.img
glance image-create --name=Trusty-RAW --visibility=public --container-format=bare --disk-format=raw <  /srv/data/trusty-server-cloudimg-amd64-root.tar.gz
exit
